@@ -3,14 +3,15 @@ set -e
 CUR_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
 cd $CUR_DIR/../
 
-CRATES=("protos" "app" "integrations/gmail" "." "exm")
+# "protos" "app" "integrations/gmail" 
+CRATES=("." "exm")
 
-echo "Checking crates..."
-for CRATE in "${CRATES[@]}"; do
-  pushd $CUR_DIR/../$CRATE
-  cargo check
-  popd
-done
+# echo "Checking crates..."
+# for CRATE in "${CRATES[@]}"; do
+#   pushd $CUR_DIR/../$CRATE
+#   cargo check
+#   popd
+# done
 
 ####
 
@@ -23,7 +24,7 @@ fi
 echo "Publishing to crates.io..."
 for CRATE in "${CRATES[@]}"; do
   pushd $CUR_DIR/../$CRATE
-  cargo publish --no-verify # no verify since we check build before
+  cargo publish --no-verify --allow-dirty # no verify since we check build before
 
   echo "Waiting 30 seconds for crates.io to publish before next crate..."
   sleep 30
